# django-ldaporm

`django-ldaporm` provides  Django ORM-like module that allows you to treat ldap
object classes like RDBMS tables.  This allows you to use Django forms, fields
and views natively with ldap models.

## Installing django-ldaporm

`django-ldaporm` is a pure python package.  As such, it can be installed in the
usual python ways.  For the following instructions, either install it into your
global python install, or use a python [virtual
environment](https://python-guide-pt-br.readthedocs.io/en/latest/dev/virtualenvs/)
to install it without polluting your global python environment.

### Install via pip

    pip install django-ldaporm
